View source: R/get_vernacularname.R
| get_common_name | R Documentation |
This function retrieves vernacular (common) names for a given species using IUCN data.
It filters vernacular names based on matching internal_taxon_id and merges
them with species metadata.
get_common_name(splist)
splist |
A character vector containing the scientific names of species for which vernacular names are to be retrieved. |
The function retrieves IUCN data for the input species, extracts the corresponding core_id, filters the vernacular name dataset using the core_id, and concatenates all unique vernacular names for each species.
A data.table or data.frame with columns:
The scientific name of the species as submitted.
A character string that contains the concatenated vernacular names for each species, separated by " - ".
species <- c("Panthera uncia", "Cedrela odorata")
result <- get_common_name(splist = species)
print(result)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.