Skip to contents

[Experimental]

Filters IUCN species and conservation status data by higher taxonomic ranks such as kingdom, phylum, class, order, family, or genus.

Usage

get_iucn_by_taxonomy(
  kingdom = NULL,
  phylum = NULL,
  class = NULL,
  order = NULL,
  family = NULL,
  genus = NULL,
  status = NULL,
  format = "tbl"
)

Arguments

kingdom

Optional character string or vector specifying kingdom name(s) (e.g., "PLANTAE", "ANIMALIA").

phylum

Optional character string or vector specifying phylum name(s).

class

Optional character string or vector specifying class name(s) (e.g., "MAMMALIA", "AMPHIBIA").

order

Optional character string or vector specifying order name(s) (e.g., "PRIMATES", "CARNIVORA").

family

Optional character string or vector specifying family name(s) (e.g., "FELIDAE", "ORCHIDACEAE").

genus

Optional character string or vector specifying genus name(s) (e.g., "Panthera", "Puya").

status

Optional character vector to filter by Red List conservation status category. Accepts short codes (e.g., "CR", "EN", "VU", "NT", "LC", "DD", "EX", "EW") or full names (e.g., "Critically Endangered").

format

A character string specifying the output format:

  • "tbl": Returns a tibble with taxonomic hierarchy and Red List status (default).

  • "vect": Returns a character vector of scientific names.

Value

Depending on format: a tibble or a character vector of species scientific names.

Examples

# Search Endangered or Critically Endangered species in Felidae family
felidae_threatened <- get_iucn_by_taxonomy(
  family = "Felidae",
  status = c("CR", "EN"),
  format = "tbl"
)
head(felidae_threatened)
#> # A tibble: 4 × 10
#>   taxonID scientificName                 kingdom phylum class order family genus
#>   <chr>   <chr>                          <chr>   <chr>  <chr> <chr> <chr>  <chr>
#> 1 15452   Leopardus jacobita (Cornalia,… ANIMAL… CHORD… MAMM… CARN… FELID… Leop…
#> 2 15955   Panthera tigris (Linnaeus, 17… ANIMAL… CHORD… MAMM… CARN… FELID… Pant…
#> 3 18148   Prionailurus planiceps (Vigor… ANIMAL… CHORD… MAMM… CARN… FELID… Prio…
#> 4 4037    Catopuma badia (Gray, 1874)    ANIMAL… CHORD… MAMM… CARN… FELID… Cato…
#> # ℹ 2 more variables: redlist_category <chr>, taxonomicStatus <chr>