Skip to contents

This function matches a dataframe of species names (submitted_name) to the IUCN database using fuzzy string matching. It returns a dataframe with matched and unmatched entries, including additional details on the matching process.

Usage

species_fuzzy_match(df)

Arguments

df

A dataframe containing species names in the column submitted_name and their matched genera in matched_genus.

Value

A dataframe with the original input, matched species names, fuzzy string distances, and match status.

Examples

df <- filter_iucn_genus("Panthera uncia")
#> 
#> ── Matching names to IUCN genus list ───────────────────────────────────────────
#>  All input genera were matched successfully (1 exact, 0 fuzzy).
species_fuzzy_match(df)
#> # A tibble: 1 × 9
#>   submitted_name    id or_genus_name matched_genus direct_match_genus
#>   <chr>          <int> <chr>         <chr>         <lgl>             
#> 1 Panthera uncia     1 Panthera      Panthera      TRUE              
#> # ℹ 4 more variables: fuzzy_match_genus <lgl>, matched_species <chr>,
#> #   fuzzy_sp_dist <dbl>, fuzzy_match_species <lgl>