Matches the genus names from a given tibble to a reference IUCN genus dataset and returns a tibble with the matching status.
Value
A tibble with the following columns:
- submitted_name
Original submitted name from the input tibble.
- or_genus_name
Original genus name from the input tibble.
- matched_genus
Matched genus name from the IUCN reference dataset, or
NAif no match was found.- direct_match_genus
Logical column indicating whether the genus was successfully matched (
TRUE) or not (FALSE).
Details
The function:
Matches the genus names in
or_genus_nameto the IUCN genus dataset (iucnr::iucn_genus).Combines matched and unmatched rows, adding a boolean indicator column (
direct_match_genus) to show match status.
The reference dataset iucnr::iucn_genus is an internal dataset included
in the iucrn package.