View source: R/get_conservation_status.R
| get_conservation_status | R Documentation |
This function retrieves the conservation status of species from the iucn_data dataset. It is vectorized to handle multiple species names and optimized using data.table for performance.
get_conservation_status(splist)
splist |
A character vector of species names to search for in the iucn_data dataset. |
A data.table with species names and their corresponding conservation status or "no match found".
species <- c("Panthera uncia", "Cedrela odorata")
result <- get_conservation_status(splist = species)
print(result)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.